WireTime class final
A C0 HH:mm:ss local wall-clock time.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- hour → int
-
Hour of day,
0through23.final - minute → int
-
Minute of hour,
0through59.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- second → int
-
Second of minute,
0through59. C0 carries no leap second.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override